# mgcomm 0.1.0 changelog

## Changes since 0.0.0:

### New features

* Added the following environment handling functions:

    - `env.home` to return user's home directory
    - `env.var_split` to split environmet variables

* Added the following functions for handling Freedesktops XDG Base Directory
  specs:

    - `xdg.config` to find application's configuration file
    - `xdg.config_dir` to find application's configuration directory
